pub struct HostBacking;Expand description
The process’s own address space.
The default backing. Uses placeholder reservations on Windows and mmap on
unix, both of which let a block be committed into part of a larger
reservation and taken back out without disturbing its neighbours.