PhysicalMemoryAccounting

Enum PhysicalMemoryAccounting 

pub enum PhysicalMemoryAccounting {
    Buffer,
    Backing {
        authority: MemoryAuthorityId,
    },
}
Who charges physical memory committed by a VirtualBacking.

Variants



Buffer

VirtualBuffer leases mapped physical bytes.



Backing

The backing’s authority owns physical bytes independently of mappings.

This is the contract for a physical-handle pool: pooled-unmapped bytes remain charged to authority, while mapped holder/zone bytes are only attribution and must not be charged as additional physical ownership.

Fields

authority: MemoryAuthorityId

The one ledger that owns every physical byte held by the backing.